#
# spec file for package python-weblate-schemas
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-weblate-schemas
Version:        2024.2
Release:        1.1
Summary:        A collection of schemas used by Weblate
License:        MIT
URL:            https://weblate.org/
Source:         https://files.pythonhosted.org/packages/source/w/weblate_schemas/weblate_schemas-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module fedora-messaging}
BuildRequires:  %{python_module fqdn >= 1.5.1}
BuildRequires:  %{python_module jsonschema-format}
BuildRequires:  %{python_module jsonschema}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module rfc3987 >= 1.3.8}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module strict-rfc3339 >= 0.7}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-fqdn >= 1.5.1
Requires:       python-jsonschema
Requires:       python-rfc3987 >= 1.3.8
Requires:       python-strict-rfc3339 >= 0.7
BuildArch:      noarch
%python_subpackages

%description
This module contains schemas used in Weblate exports.

%prep
%setup -q -n weblate_schemas-%{version}
%autopatch -p1
sed -i -e '/pytest-runner/d' setup.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/weblate_schemas
%{python_sitelib}/weblate_schemas-%{version}.dist-info

%changelog
* Tue Jan  7 2025 Markéta Machová <mmachova@suse.com>
- update to 2024.2
  * Added schema for Weblate Fedora Messaging.
  * Added support for Python 3.13.
  * Clarified language field in the component backup schema.
* Thu Jun 13 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.1:
  * Dropped support for Python 3.7 and 3.8.
  * Added support for Python 3.12.
  * Clarified address field on user data.
* Sat Jul  1 2023 Markéta Machová <mmachova@suse.com>
- Update to 2023.3
  * Added support for Python 3.11 and 3.10.
  * Dropped support for Python 3.6.
  * Fixed project backups schema to allow blank project website.
  * Fixed project backup with unicode website URLs.
  * Added theme to user data.
- Drop upstreamed test-data.patch
* Thu Oct 27 2022 Markéta Machová <mmachova@suse.com>
- Update to version 2022.1
  * Added validate_schema API.
  * Added caching to schema loading.
  * Added timestamp validation.
  * Switched to CalVer versioning.
  * Added schema for component backups.
  * Added schema for project backups.
- Add upstream test-data.patch
* Thu Jul  1 2021 Markéta Machová <mmachova@suse.com>
- Update to version 0.7
  * Fixed minor syntax issue in user data schema.
* Mon Mar 15 2021 Markéta Machová <mmachova@suse.com>
- Update to version 0.6
  * Fixed license information.
  * Fixed validation of translation memory entries with newlines.
* Wed Aug 19 2020 Matthias Fehring <buschmann23@opensuse.org>
- Update to version 0.4
  * Added schema for user downloadable data.
* Fri Apr 17 2020 Tomáš Chvátal <tchvatal@suse.com>
- Initial commit, needed by weblate
